/*
 *  Copyright (c) Members of the EGEE Collaboration. 2005.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Utilities
 *
 *  Authors: Gabor Gombas <Gabor.Gombas@cern.ch>
 *  Version info: $Id: glite-cfg-util.h,v 1.1 2005/06/07 09:35:07 szamsu Exp $
 *  Release: $Name: emi-service-discovery-file-c_R_2_1_2_3 $
 *
 *
 */

#ifndef GLITE_CFG_UTIL_H
#define GLITE_CFG_UTIL_H

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Names of the environment variables that define the location of gLite
 * components.
 */
#define GLITE_LOCATION			"GLITE_LOCATION"
#define GLITE_LOCATION_VAR		"GLITE_LOCATION_VAR"
#define GLITE_LOCATION_LOG		"GLITE_LOCATION_LOG"
#define GLITE_TMP			"GLITE_TMP"

/**
 * \defgroup glite_util GLITE Utils
 * @{
 */

/** 
 * \brief Retrieve the value of "key" from either the environment or from
 * glite.conf. 
 *
 * @param key [IN] the key of which the value we are looking for.
 *
 * @return the associated value.
 * 
 */
const char *glite_conf_value(const char *key);

/**
 * \brief Get the value of GLITE_LOCATION. 
 *
 * @return the value of GLITE_LOCATION. Never returns NULL.
 */
const char *glite_location(void);

/** 
 * \brief Get the value of GLITE_LOCATION_VAR.
 *
 * @return the value of GLITE_LOCATION_VAR. 
 */
const char *glite_location_var(void);

/**
 * \brief Get the directory where logfiles should be stored.
 * 
 * @return the directory where logfiles should be stored.
 */   
const char *glite_location_log(void);

/** 
 * \brief Get the value of GLITE_TMP.
 *
 * @return the value of GLITE_TMP. Never returns NULL.
 */
const char *glite_tmp(void);

/** 
 * Get the value of any glite package.
 *
 * @return the value of GLITE_<pkg>_<var> from either the environment,
 * or from glite.conf. Returns NULL if the variable is not defined.
 */
const char *glite_pkg_var(const char *pkg, const char *var);

/**
 * \brief Get the full path of a configuration file.
 *
 * The function will first try
 * to look under $HOME/.glite/etc if look_in_home is TRUE, then under
 * $GLITE_LOCATION_VAR/etc, then under $GLITE_LOCATION/etc.
 *
 * @return the path of the first existing configuration file.
 * If no configuration file was found, NULL is returned.
 */
char *glite_config_file(const char *file, int look_in_home);

/**
 * @}
 */

#ifdef __cplusplus
}
#endif

#endif /* GLITE_CFG_UTIL_H */
